@@ -128,6 +128,15 @@ EOF
     fi
 }
 
+extract_jce() {
+  local zip_file="$1"
+  local dest_dir="$2"
+
+  echo "Installing unlimited strength cryptography files using $zip_file"
+  for f in {US_export,local}_policy.jar; do
+    unzip -o -j -d "$dest_dir" "$zip_file" "*/$f"
+  done
+}
 
 read_maintainer_info() {
     if [ -z "$maintainer_name" ]; then
@@ -193,12 +202,10 @@ get_architecture() {
     echo "Detected Debian GNU type: ${DEB_BUILD_GNU_TYPE:-N/A}"
 }
 
-# get browser plugin directories
-get_browser_plugin_dirs() {
-    if dpkg-vendor --derives-from Ubuntu; then
-        export browser_plugin_dirs="xulrunner-addons firefox iceape iceweasel mozilla midbrowser xulrunner"
+get_distribution() {
+    if [ -n "$distribution" ]; then
+      target_distribution="$distribution"
     else
-        export browser_plugin_dirs=mozilla
+      target_distribution="unstable"
     fi
 }
-
